@@ -9,7 +9,7 @@ import redis
 import docker
 import socket
 import websockets
-from websockets.exceptions import InvalidStatusCode
+from websockets.exceptions import InvalidStatusCode, ConnectionClosed, ConnectionClosedOK
 from tickerdax.constants import Envs, KeyTypes, NAME
 from docker.errors import DockerException
 from datetime import datetime, timedelta, timezone
@@ -275,6 +275,11 @@ class TickerDax:
                             self._redis_client.set(key, json.dumps(data))
                             self._logger.info(f'Cached: {pformat(data)}')
 
+        except (ConnectionClosed, ConnectionClosedOK) as error:
+            self._logger.error(error)
+            # re-connect if the connection was closed
+            await self._stream_to_cache(route, symbols)
+
         except InvalidStatusCode as error:
             if error.status_code == 401:
                 self.report_error(
